@@ -1,7 +1,7 @@
 import logging
 
 from OBP_reliability_pillar.dynamodb.dynamodb_autoscaling_enabled import dynamodb_autoscaling_enabled
-
+from OBP_reliability_pillar.dynamodb.dynamodb_pitr_enabled import dynamodb_pitr_enabled
 
 logging.basicConfig(level=logging.INFO)
 logger = logging.getLogger()
@@ -17,6 +17,7 @@ def dynamodb_compliance(self) -> list:
 
     response = [
         dynamodb_autoscaling_enabled(self),
+        dynamodb_pitr_enabled(self),
     ]
 
     return response
\ No newline at end of file
