@@ -23,7 +23,7 @@ def list_lambda_functions(client) -> dict:
                 Marker=marker
             )
         for fn in response['Functions']:
-            function_lst.append(fn['FunctionName'])
+            function_lst.append(fn)
 
         try:
             marker = response['NextMarker']
