@@ -1,4 +1,5 @@
 from OBP_reliability_pillar.rds.rds_automatic_minor_version_upgrade_enabled import *
+from OBP_reliability_pillar.rds.rds_backup_enabled import rds_backup_enabled
 from OBP_reliability_pillar.rds.rds_enhanced_monitoring_enabled import *
 from OBP_reliability_pillar.rds.rds_multi_az_support_enabled import *
 from OBP_reliability_pillar.rds.rds_instance_deletion_protection_enabled import *
@@ -19,7 +20,8 @@ def rds_compliance(self) -> list:
         rds_multi_az_support_enabled(self),
         rds_instance_deletion_protection_enabled(self),
         rds_enhanced_monitoring_enabled(self),
-        rds_automatic_minor_version_upgrade_enabled(self)
+        rds_automatic_minor_version_upgrade_enabled(self),
+        rds_backup_enabled(self),
     ]
 
     return response
\ No newline at end of file
