@@ -1,5 +1,7 @@
 import logging
 from OBP_reliability_pillar.redshift.redshift_backup_enabled import redshift_backup_enabled
+from OBP_reliability_pillar.redshift.redshift_cluster_maintenancesettings_check import \
+    redshift_cluster_maintenance_settings_check
 
 logging.basicConfig(level=logging.INFO)
 logger = logging.getLogger()
@@ -14,7 +16,8 @@ def  redshift_compliance(self) -> list:
     logger.info(" ---Inside redshift :: redshift_compliance()")
 
     response = [
-        redshift_backup_enabled(self)
+        redshift_backup_enabled(self),
+        redshift_cluster_maintenance_settings_check(self),
     ]
 
     return response
\ No newline at end of file
