@@ -1,4 +1,6 @@
 import logging
+
+from OBP_reliability_pillar.s3.s3_bucket_default_lock_enabled import s3_bucket_default_lock_enabled
 from OBP_reliability_pillar.s3.s3_bucket_replication_enabled import s3_bucket_replication_enabled
 from OBP_reliability_pillar.s3.s3_bucket_versioning_enabled import s3_bucket_versioning_enabled
 
@@ -16,7 +18,8 @@ def s3_compliance(self) -> list:
 
     response = [
         s3_bucket_replication_enabled(self),
-        s3_bucket_versioning_enabled(self)
+        s3_bucket_versioning_enabled(self),
+        s3_bucket_default_lock_enabled(self)
     ]
 
     return response
\ No newline at end of file
